@@ -646,589 +646,6 @@ def get_featuregroup_partitions(featuregroup, featurestore=None, featuregroup_ve
                                                     core._get_featurestore_metadata(featurestore, update_cache=True),
                                                     featurestore, featuregroup_version)
 
-
-def visualize_featuregroup_distributions(featuregroup_name, featurestore=None, featuregroup_version=1, figsize=None,
-                                         color='lightblue', log=False, align="center", plot=True):
-    """
-    Visualizes the feature distributions (if they have been computed) for a featuregroup in the featurestore
-
-    Example usage:
-
-    >>> featurestore.visualize_featuregroup_distributions("trx_summary_features")
-    >>> # You can also explicitly define version, featurestore and plotting options
-    >>> featurestore.visualize_featuregroup_distributions("trx_summary_features",
-    >>>                                                  featurestore=featurestore.project_featurestore(),
-    >>>                                                  featuregroup_version = 1,
-    >>>                                                  color="lightblue",
-    >>>                                                  figsize=(16,12),
-    >>>                                                  log=False,
-    >>>                                                  align="center",
-    >>>                                                  plot=True)
-
-    Args:
-        :featuregroup_name: the name of the featuregroup
-        :featurestore: the featurestore where the featuregroup resides
-        :featuregroup_version: the version of the featuregroup
-        :figsize: size of the figure
-        :figsize: the size of the figure
-        :color: the color of the histograms
-        :log: whether to use log-scaling on the y-axis or not
-        :align: how to align the bars, defaults to center.
-        :plot: if set to True it will plot the image and return None, if set to False it will not plot it
-               but rather return the figure
-
-    Returns:
-        if the 'plot' flag is set to True it will plot the image and return None, if the 'plot' flag is set to False
-        it will not plot it but rather return the figure
-
-    Raises:
-        :FeatureVisualizationError: if there was an error visualizing the feature distributions
-    """
-    if plot:
-        fs_utils._visualization_validation_warning()
-
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        # Construct the figure
-        fig = core._do_visualize_featuregroup_distributions(featuregroup_name, featurestore, featuregroup_version,
-                                                            figsize=figsize, color=color, log=log, align=align)
-        if plot:
-            # Plot the figure
-            fig.tight_layout()
-        else:
-            return fig
-    except:
-        # Retry with updated cache
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        try:
-            # Construct the figure
-            fig = core._do_visualize_featuregroup_distributions(featuregroup_name, featurestore, featuregroup_version,
-                                                                figsize=figsize, color=color, log=log, align=align)
-            if plot:
-                # Plot the figure
-                fig.tight_layout()
-            else:
-                return fig
-
-        except Exception as e:
-            raise FeatureVisualizationError("There was an error in visualizing the feature distributions for "
-                                            "feature group: {} with version: {} in featurestore: {}. Error: {}".format(
-                featuregroup_name, featuregroup_version, featurestore, str(e)))
-
-
-def visualize_featuregroup_correlations(featuregroup_name, featurestore=None, featuregroup_version=1, figsize=(16,12),
-                                        cmap="coolwarm", annot=True, fmt=".2f", linewidths=.05, plot=True):
-    """
-    Visualizes the feature correlations (if they have been computed) for a featuregroup in the featurestore
-
-    Example usage:
-
-    >>> featurestore.visualize_featuregroup_correlations("trx_summary_features")
-    >>> # You can also explicitly define version, featurestore and plotting options
-    >>> featurestore.visualize_featuregroup_correlations("trx_summary_features",
-    >>>                                                  featurestore=featurestore.project_featurestore(),
-    >>>                                                  featuregroup_version = 1,
-    >>>                                                  cmap="coolwarm",
-    >>>                                                  figsize=(16,12),
-    >>>                                                  annot=True,
-    >>>                                                  fmt=".2f",
-    >>>                                                  linewidths=.05
-    >>>                                                  plot=True)
-
-    Args:
-        :featuregroup_name: the name of the featuregroup
-        :featurestore: the featurestore where the featuregroup resides
-        :featuregroup_version: the version of the featuregroup
-        :figsize: the size of the figure
-        :cmap: the color map
-        :annot: whether to annotate the heatmap
-        :fmt: how to format the annotations
-        :linewidths: line width in the plot
-        :plot: if set to True it will plot the image and return None, if set to False it will not plot it
-               but rather return the figure
-
-    Returns:
-        if the 'plot' flag is set to True it will plot the image and return None, if the 'plot' flag is set to False
-        it will not plot it but rather return the figure
-
-    Raises:
-        :FeatureVisualizationError: if there was an error visualizing the feature correlations
-    """
-    if plot:
-        fs_utils._visualization_validation_warning()
-
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        if update_cache_default:
-            core._get_featurestore_metadata(featurestore, update_cache=True)
-        # Construct the figure
-        fig = core._do_visualize_featuregroup_correlations(featuregroup_name, featurestore, featuregroup_version,
-                                                            figsize=figsize, cmap=cmap, annot=annot, fmt=fmt,
-                                                           linewidths=linewidths)
-        if plot:
-            # Plot the figure
-            fig.tight_layout()
-        else:
-            return fig
-    except:
-        # Retry with updated cache
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        try:
-            # Construct the figure
-            fig = core._do_visualize_featuregroup_correlations(featuregroup_name, featurestore, featuregroup_version,
-                                                               figsize=figsize, cmap=cmap, annot=annot, fmt=fmt,
-                                                               linewidths=linewidths)
-            if plot:
-                # Plot the figure
-                fig.tight_layout()
-            else:
-                return fig
-
-        except Exception as e:
-            raise FeatureVisualizationError("There was an error in visualizing the feature correlations for "
-                                            "feature group: {} with version: {} in featurestore: {}. Error: {}".format(
-                featuregroup_name, featuregroup_version, featurestore, str(e)))
-
-
-def visualize_featuregroup_clusters(featuregroup_name, featurestore=None, featuregroup_version=1, figsize=(16,12),
-                                    plot=True):
-    """
-    Visualizes the feature clusters (if they have been computed) for a featuregroup in the featurestore
-
-    Example usage:
-
-    >>> featurestore.visualize_featuregroup_clusters("trx_summary_features")
-    >>> # You can also explicitly define version, featurestore and plotting options
-    >>> featurestore.visualize_featuregroup_clusters("trx_summary_features",
-    >>>                                                  featurestore=featurestore.project_featurestore(),
-    >>>                                                  featuregroup_version = 1,
-    >>>                                                  figsize=(16,12),
-    >>>                                                  plot=True)
-
-    Args:
-        :featuregroup_name: the name of the featuregroup
-        :featurestore: the featurestore where the featuregroup resides
-        :featuregroup_version: the version of the featuregroup
-        :figsize: the size of the figure
-        :plot: if set to True it will plot the image and return None, if set to False it will not plot it
-               but rather return the figure
-
-    Returns:
-        if the 'plot' flag is set to True it will plot the image and return None, if the 'plot' flag is set to False
-        it will not plot it but rather return the figure
-
-    Raises:
-        :FeatureVisualizationError: if there was an error visualizing the feature clusters
-    """
-    if plot:
-        fs_utils._visualization_validation_warning()
-
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        if update_cache_default:
-            core._get_featurestore_metadata(featurestore, update_cache=True)
-        # Construct the figure
-        fig = core._do_visualize_featuregroup_clusters(featuregroup_name, featurestore, featuregroup_version,
-                                                           figsize=figsize)
-        if plot:
-            # Plot the figure
-            fig.tight_layout()
-        else:
-            return fig
-    except:
-        # Retry with updated cache
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        try:
-            # Construct the figure
-            fig = core._do_visualize_featuregroup_clusters(featuregroup_name, featurestore, featuregroup_version,
-                                                               figsize=figsize)
-            if plot:
-                # Plot the figure
-                fig.tight_layout()
-            else:
-                return fig
-
-        except Exception as e:
-            raise FeatureVisualizationError("There was an error in visualizing the feature clusters for "
-                                            "feature group: {} with version: {} in featurestore: {}. Error: {}".format(
-                featuregroup_name, featuregroup_version, featurestore, str(e)))
-
-
-def visualize_featuregroup_descriptive_stats(featuregroup_name, featurestore=None, featuregroup_version=1):
-    """
-    Visualizes the descriptive stats (if they have been computed) for a featuregroup in the featurestore
-
-    Example usage:
-
-    >>> featurestore.visualize_featuregroup_descriptive_stats("trx_summary_features")
-    >>> # You can also explicitly define version, featurestore and plotting options
-    >>> featurestore.visualize_featuregroup_descriptive_stats("trx_summary_features",
-    >>>                                                  featurestore=featurestore.project_featurestore(),
-    >>>                                                  featuregroup_version = 1)
-
-    Args:
-        :featuregroup_name: the name of the featuregroup
-        :featurestore: the featurestore where the featuregroup resides
-        :featuregroup_version: the version of the featuregroup
-
-    Returns:
-        A pandas dataframe with the descriptive statistics
-
-    Raises:
-        :FeatureVisualizationError: if there was an error in fetching the descriptive statistics
-    """
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        if update_cache_default:
-            core._get_featurestore_metadata(featurestore, update_cache=True)
-        df = core._do_visualize_featuregroup_descriptive_stats(featuregroup_name, featurestore,
-                                                                   featuregroup_version)
-        return df
-    except:
-        # Retry with updated cache
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        try:
-            df = core._do_visualize_featuregroup_descriptive_stats(featuregroup_name, featurestore,
-                                                                       featuregroup_version)
-            return df
-
-        except Exception as e:
-            raise FeatureVisualizationError("There was an error in visualizing the descriptive statistics for "
-                                            "featuregroup: {} with version: {} in featurestore: {}. "
-                                            "Error: {}".format(featuregroup_name, featuregroup_version,
-                                                               featurestore, str(e)))
-
-
-def visualize_training_dataset_distributions(training_dataset_name, featurestore=None, training_dataset_version=1,
-                                             figsize=(16, 12), color='lightblue', log=False, align="center", plot=True):
-    """
-    Visualizes the feature distributions (if they have been computed) for a training dataset in the featurestore
-
-    Example usage:
-
-    >>> featurestore.visualize_training_dataset_distributions("AML_dataset")
-    >>> # You can also explicitly define version, featurestore and plotting options
-    >>> featurestore.visualize_training_dataset_distributions("AML_dataset",
-    >>>                                                  featurestore=featurestore.project_featurestore(),
-    >>>                                                  training_dataset_version = 1,
-    >>>                                                  color="lightblue",
-    >>>                                                  figsize=(16,12),
-    >>>                                                  log=False,
-    >>>                                                  align="center",
-    >>>                                                  plot=True)
-
-    Args:
-        :training_dataset_name: the name of the training dataset
-        :featurestore: the featurestore where the training dataset resides
-        :training_dataset_version: the version of the training dataset
-        :figsize: size of the figure
-        :figsize: the size of the figure
-        :color: the color of the histograms
-        :log: whether to use log-scaling on the y-axis or not
-        :align: how to align the bars, defaults to center.
-        :plot: if set to True it will plot the image and return None, if set to False it will not plot it
-               but rather return the figure
-
-    Returns:
-        if the 'plot' flag is set to True it will plot the image and return None, if the 'plot' flag is set to False
-        it will not plot it but rather return the figure
-
-    Raises:
-        :FeatureVisualizationError: if there was an error visualizing the feature distributions
-    """
-    if plot:
-        fs_utils._visualization_validation_warning()
-
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        if update_cache_default:
-            core._get_featurestore_metadata(featurestore, update_cache=True)
-        # Construct the figure
-        fig = core._do_visualize_training_dataset_distributions(training_dataset_name, featurestore,
-                                                            training_dataset_version, figsize=figsize, color=color,
-                                                            log=log, align=align)
-        if plot:
-            # Plot the figure
-            fig.tight_layout()
-        else:
-            return fig
-    except:
-        # Retry with updated cache
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        try:
-            # Construct the figure
-            fig = core._do_visualize_training_dataset_distributions(training_dataset_name, featurestore,
-                                                                training_dataset_version, figsize=figsize, color=color,
-                                                                log=log, align=align)
-            if plot:
-                # Plot the figure
-                fig.tight_layout()
-            else:
-                return fig
-
-        except Exception as e:
-            raise FeatureVisualizationError("There was an error in visualizing the feature distributions for "
-                                            "training dataset: {} with version: {} in featurestore: {}. "
-                                            "Error: {}".format(training_dataset_name, training_dataset_version,
-                                                               featurestore, str(e)))
-
-
-def visualize_training_dataset_correlations(training_dataset_name, featurestore=None, training_dataset_version=1,
-                                            figsize=(16,12), cmap="coolwarm", annot=True, fmt=".2f",
-                                            linewidths=.05, plot=True):
-    """
-    Visualizes the feature distributions (if they have been computed) for a training dataset in the featurestore
-
-    Example usage:
-
-    >>> featurestore.visualize_training_dataset_correlations("AML_dataset")
-    >>> # You can also explicitly define version, featurestore and plotting options
-    >>> featurestore.visualize_training_dataset_correlations("AML_dataset",
-    >>>                                                  featurestore=featurestore.project_featurestore(),
-    >>>                                                  training_dataset_version = 1,
-    >>>                                                  cmap="coolwarm",
-    >>>                                                  figsize=(16,12),
-    >>>                                                  annot=True,
-    >>>                                                  fmt=".2f",
-    >>>                                                  linewidths=.05
-    >>>                                                  plot=True)
-
-    Args:
-        :training_dataset_name: the name of the training dataset
-        :featurestore: the featurestore where the training dataset resides
-        :training_dataset_version: the version of the training dataset
-        :figsize: the size of the figure
-        :cmap: the color map
-        :annot: whether to annotate the heatmap
-        :fmt: how to format the annotations
-        :linewidths: line width in the plot
-        :plot: if set to True it will plot the image and return None, if set to False it will not plot it
-               but rather return the figure
-
-    Returns:
-        if the 'plot' flag is set to True it will plot the image and return None, if the 'plot' flag is set to False
-        it will not plot it but rather return the figure
-
-    Raises:
-        :FeatureVisualizationError: if there was an error visualizing the feature correlations
-    """
-    if plot:
-        fs_utils._visualization_validation_warning()
-
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        if update_cache_default:
-            core._get_featurestore_metadata(featurestore, update_cache=True)
-        # Construct the figure
-        fig = core._do_visualize_training_dataset_correlations(training_dataset_name, featurestore,
-                                                               training_dataset_version, figsize=figsize, cmap=cmap,
-                                                               annot=annot, fmt=fmt, linewidths=linewidths)
-        if plot:
-            # Plot the figure
-            fig.tight_layout()
-        else:
-            return fig
-    except:
-        # Retry with updated cache
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        try:
-            # Construct the figure
-            fig = core._do_visualize_training_dataset_correlations(training_dataset_name, featurestore,
-                                                                   training_dataset_version, figsize=figsize,
-                                                                   cmap=cmap, annot=annot, fmt=fmt,
-                                                                   linewidths=linewidths)
-            if plot:
-                # Plot the figure
-                fig.tight_layout()
-            else:
-                return fig
-
-        except Exception as e:
-            raise FeatureVisualizationError("There was an error in visualizing the feature correlations for "
-                                            "training dataset: {} with version: {} in featurestore: {}. "
-                                            "Error: {}".format(training_dataset_name, training_dataset_version,
-                                                               featurestore, str(e)))
-
-
-def visualize_training_dataset_clusters(training_dataset_name, featurestore=None, training_dataset_version=1,
-                                        figsize=(16,12), plot=True):
-    """
-    Visualizes the feature clusters (if they have been computed) for a training dataset in the featurestore
-
-    Example usage:
-
-    >>> featurestore.visualize_training_dataset_clusters("AML_dataset")
-    >>> # You can also explicitly define version, featurestore and plotting options
-    >>> featurestore.visualize_training_dataset_clusters("AML_dataset",
-    >>>                                                  featurestore=featurestore.project_featurestore(),
-    >>>                                                  training_dataset_version = 1,
-    >>>                                                  figsize=(16,12),
-    >>>                                                  plot=True)
-
-    Args:
-        :training_dataset_name: the name of the training dataset
-        :featurestore: the featurestore where the training dataset resides
-        :training_dataset_version: the version of the training dataset
-        :figsize: the size of the figure
-        :plot: if set to True it will plot the image and return None, if set to False it will not plot it
-               but rather return the figure
-
-    Returns:
-        if the 'plot' flag is set to True it will plot the image and return None, if the 'plot' flag is set to False
-        it will not plot it but rather return the figure
-
-    Raises:
-        :FeatureVisualizationError: if there was an error visualizing the feature clusters
-    """
-    if plot:
-        fs_utils._visualization_validation_warning()
-
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        if update_cache_default:
-            core._get_featurestore_metadata(featurestore, update_cache=True)
-        # Construct the figure
-        fig = core._do_visualize_training_dataset_clusters(training_dataset_name, featurestore,
-                                                           training_dataset_version, figsize=figsize)
-        if plot:
-            # Plot the figure
-            fig.tight_layout()
-        else:
-            return fig
-    except:
-        # Retry with updated cache
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        try:
-            # Construct the figure
-            fig = core._do_visualize_training_dataset_clusters(training_dataset_name, featurestore,
-                                                               training_dataset_version, figsize=figsize)
-            if plot:
-                # Plot the figure
-                fig.tight_layout()
-            else:
-                return fig
-
-        except Exception as e:
-            raise FeatureVisualizationError("There was an error in visualizing the feature clusters for "
-                                            "training dataset: {} with version: {} in featurestore: {}. "
-                                            "Error: {}".format(training_dataset_name, training_dataset_version,
-                                                               featurestore, str(e)))
-
-
-def visualize_training_dataset_descriptive_stats(training_dataset_name, featurestore=None, training_dataset_version=1):
-    """
-    Visualizes the descriptive stats (if they have been computed) for a training dataset in the featurestore
-
-    Example usage:
-
-    >>> featurestore.visualize_training_dataset_descriptive_stats("AML_dataset")
-    >>> # You can also explicitly define version and featurestore
-    >>> featurestore.visualize_training_dataset_descriptive_stats("AML_dataset",
-    >>>                                                  featurestore=featurestore.project_featurestore(),
-    >>>                                                  training_dataset_version = 1)
-
-    Args:
-        :training_dataset_name: the name of the training dataset
-        :featurestore: the featurestore where the training dataset resides
-        :training_dataset_version: the version of the training dataset
-
-    Returns:
-        A pandas dataframe with the descriptive statistics
-
-    Raises:
-        :FeatureVisualizationError: if there was an error in fetching the descriptive statistics
-    """
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        if update_cache_default:
-            core._get_featurestore_metadata(featurestore, update_cache=True)
-        df = core._do_visualize_training_dataset_descriptive_stats(training_dataset_name, featurestore,
-                                                                   training_dataset_version)
-        return df
-    except:
-        # Retry with updated cache
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        try:
-            df = core._do_visualize_training_dataset_descriptive_stats(training_dataset_name, featurestore,
-                                                                       training_dataset_version)
-            return df
-
-        except Exception as e:
-            raise FeatureVisualizationError("There was an error in visualizing the descriptive statistics for "
-                                            "training dataset: {} with version: {} in featurestore: {}. "
-                                            "Error: {}".format(training_dataset_name, training_dataset_version,
-                                                               featurestore, str(e)))
-
-
-def get_featuregroup_statistics(featuregroup_name, featurestore=None, featuregroup_version=1):
-    """
-    Gets the computed statistics (if any) of a featuregroup
-
-    Example usage:
-
-    >>> stats = featurestore.get_featuregroup_statistics("trx_summary_features")
-    >>> # You can also explicitly define version and featurestore
-    >>> stats = featurestore.get_featuregroup_statistics("trx_summary_features",
-    >>>                                                  featurestore=featurestore.project_featurestore(),
-    >>>                                                  featuregroup_version = 1)
-
-    Args:
-        :featuregroup_name: the name of the featuregroup
-        :featurestore: the featurestore where the featuregroup resides
-        :featuregroup_version: the version of the featuregroup
-
-    Returns:
-          A Statistics Object
-    """
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        if update_cache_default:
-            core._get_featurestore_metadata(featurestore, update_cache=True)
-        return core._do_get_featuregroup_statistics(featuregroup_name, featurestore, featuregroup_version)
-    except:
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        return core._do_get_featuregroup_statistics(featuregroup_name, featurestore, featuregroup_version)
-
-
-def get_training_dataset_statistics(training_dataset_name, featurestore=None, training_dataset_version=1):
-    """
-    Gets the computed statistics (if any) of a training dataset
-
-    Example usage:
-
-    >>> stats = featurestore.get_training_dataset_statistics("AML_dataset")
-    >>> # You can also explicitly define version and featurestore
-    >>> stats = featurestore.get_training_dataset_statistics("AML_dataset",
-    >>>                                                      featurestore=featurestore.project_featurestore(),
-    >>>                                                      training_dataset_version = 1)
-
-    Args:
-        :training_dataset_name: the name of the training dataset
-        :featurestore: the featurestore where the training dataset resides
-        :training_dataset_version: the version of the training dataset
-
-    Returns:
-          A Statistics Object
-    """
-    if featurestore is None:
-        featurestore = project_featurestore()
-    try:
-        if update_cache_default:
-            core._get_featurestore_metadata(featurestore, update_cache=True)
-        return core._do_get_training_dataset_statistics(training_dataset_name, featurestore, training_dataset_version)
-    except:
-        core._get_featurestore_metadata(featurestore, update_cache=True)
-        return core._do_get_training_dataset_statistics(training_dataset_name, featurestore, training_dataset_version)
-
 def import_featuregroup_s3(storage_connector, featuregroup, path=None, primary_key=[], description="",
                            featurestore=None, featuregroup_version=1, jobs=[], descriptive_statistics=True,
                            feature_correlation=True, feature_histograms=True, cluster_analysis=True, stat_columns=None,
@@ -1482,9 +899,7 @@ def get_online_featurestore_connector(featurestore=None):
 def create_training_dataset(training_dataset, features=None, sql_query=None, featurestore=None,
                             featuregroups_version_dict={}, join_key=None, description="", data_format="tfrecords",
                             training_dataset_version=1, overwrite=False, jobs=[], online=False,
-                            descriptive_statistics=True, feature_correlation=True, feature_histograms=True,
-                            cluster_analysis=True, stat_columns=[], num_bins=20, correlation_method='pearson',
-                            num_clusters=5, fixed=True, sink=None, path=None, am_cores=1, am_memory=2048,
+                            fixed=True, sink=None, path=None, am_cores=1, am_memory=2048,
                             executor_cores=1, executor_memory=4096, max_executors=2):
     """
     Creates and triggers a job to create a training dataset of features from a featurestore in Hopsworks.
@@ -1497,10 +912,7 @@ def create_training_dataset(training_dataset, features=None, sql_query=None, fea
     >>> # You can override the default configuration if necessary:
     >>> featurestore.create_training_dataset(["feature1", "feature2", "label"], "TestDataset", description="",
     >>>                                      featurestore=featurestore.project_featurestore(), data_format="csv",
-    >>>                                      training_dataset_version=1,
-    >>>                                      descriptive_statistics=False, feature_correlation=False,
-    >>>                                      feature_histograms=False, cluster_analysis=False, stat_columns=None,
-    >>>                                      sink = "s3_connector")
+    >>>                                      training_dataset_version=1, sink = "s3_connector")
 
     Args:
         :training_dataset: The name of the training dataset.
@@ -1522,17 +934,6 @@ def create_training_dataset(training_dataset, features=None, sql_query=None, fea
         :jobs: List of Hopsworks jobs linked to the training dataset. Defaults to [].
         :online: Boolean flag whether to run the query against the online featurestore (otherwise it will be the offline
             featurestore).
-        :descriptive_statistics: A boolean flag whether to compute descriptive statistics (min,max,mean etc)
-                                 for the featuregroup. Defaults to True.
-        :feature_correlation: A boolean flag whether to compute a feature correlation matrix for the numeric columns
-                              in the featuregroup. Defaults to True.
-        :feature_histograms: A boolean flag whether to compute histograms for the numeric columns in the featuregroup. Defaults to True.
-        :cluster_analysis: A boolean flag whether to compute cluster analysis for the numeric columns in the
-                           featuregroup. Defaults to True.
-        :stat_columns: A list of columns to compute statistics for. Fefaults to all columns that are numeric if `[]`.
-        :num_bins: Number of bins to use for computing histograms. Defaults to 20.
-        :correlation_method: The method to compute feature correlation with (pearson or spearman). Defaults to 'pearson'.
-        :num_clusters: Number of clusters to use for cluster analysis. Defaults to 5.
         :fixed: Boolean flag indicating whether array columns should be treated with fixed size or variable size. Defaults to True.
         :sink: Name of storage connector to store the training dataset. Defaults to the hdfs connector.
         :path: path to complement the sink storage connector with, e.g if the storage connector points to an
